@@ -20,6 +20,7 @@
 #'
 #' @param outdata An `outdata` object created by [prepare_ae_specific()].
 #' @param ci A numeric value for the percentile of confidence interval.
+#' @param ... Other options passed on to [metalite.ae::rate_compare_sum()]
 #'
 #' @return A list of analysis raw datasets.
 #'
@@ -32,10 +33,12 @@
 #'   observation = "wk12",
 #'   parameter = "rel"
 #' ) |>
-#'   extend_ae_specific_inference() |>
+#'   extend_ae_specific_inference(eps = 1e-6, bisection = 200) |>
 #'   format_ae_specific(display = c("n", "prop", "diff", "diff_ci"))
 #' head(tbl$tbl)
-extend_ae_specific_inference <- function(outdata, ci = 0.95) {
+extend_ae_specific_inference <- function(outdata,
+                                         ...,
+                                         ci = 0.95) {
   res <- outdata
 
   if (!(is.numeric(ci) && length(ci) == 1 && (0 <= ci && ci <= 1))) {
@@ -66,7 +69,9 @@ extend_ae_specific_inference <- function(outdata, ci = 0.95) {
         x0 = x0[i],
         x1 = x1[i],
         n0 = n0[i],
-        n1 = n1[i], alpha = 1 - ci
+        n1 = n1[i],
+        alpha = 1 - ci,
+        ...
       )
     }
     tmp <- bind_rows2(tmp)
@@ -164,17 +169,19 @@ extend_ae_specific_duration <- function(outdata,
   }
 
   # Add a total group to display total column
-  pop_total <- pop
-  pop_total[[pop_group]] <- "Total"
-  pop <- rbind(pop, pop_total)
   if (nrow(pop) == 0) {
     levels(pop[[pop_group]]) <- c(levels(pop[[pop_group]]), "Total")
+  } else {
+    pop_total <- pop
+    pop_total[[pop_group]] <- "Total"
+    pop <- rbind(pop, pop_total)
   }
-  obs_total <- obs
-  obs_total[[obs_group]] <- "Total"
-  obs <- rbind(obs, obs_total)
   if (nrow(obs) == 0) {
     levels(obs[[obs_group]]) <- c(levels(obs[[obs_group]]), "Total")
+  } else {
+    obs_total <- obs
+    obs_total[[obs_group]] <- "Total"
+    obs <- rbind(obs, obs_total)
   }
 
   # Group information
@@ -187,9 +194,11 @@ extend_ae_specific_duration <- function(outdata,
 
   soc_duration <- avg_duration(obs[[obs_id]], obs[[obs_group]], obs[[obs_dur]], obs[[par_soc]])
   soc_order <- outdata$order[outdata$order %% 1e3 == 0]
+  soc_order <- soc_order[order(outdata$name[outdata$order %% 1e3 == 0])]
 
   par_duration <- avg_duration(obs[[obs_id]], obs[[obs_group]], obs[[obs_dur]], obs[[par_var]])
   par_order <- outdata$order[outdata$order > 1e3 & outdata$order %% 1e3 > 0]
+  par_order <- par_order[order(outdata$name[outdata$order > 1e3 & outdata$order %% 1e3 > 0])]
 
   avg <- obs_duration$avg
   se <- obs_duration$se
@@ -240,7 +249,7 @@ extend_ae_specific_duration <- function(outdata,
 #'   parameter = "rel"
 #' ) |>
 #'   extend_ae_specific_events() |>
-#'   format_ae_specific(display = c("n", "prop", "events"))
+#'   format_ae_specific(display = c("n", "prop", "events_avg"))
 #' head(tbl$tbl)
 extend_ae_specific_events <- function(outdata) {
   meta <- outdata$meta
@@ -279,17 +288,19 @@ extend_ae_specific_events <- function(outdata) {
   }
 
   # Add a total group to display total column
-  pop_total <- pop
-  pop_total[[pop_group]] <- "Total"
-  pop <- rbind(pop, pop_total)
   if (nrow(pop) == 0) {
     levels(pop[[pop_group]]) <- c(levels(pop[[pop_group]]), "Total")
+  } else {
+    pop_total <- pop
+    pop_total[[pop_group]] <- "Total"
+    pop <- rbind(pop, pop_total)
   }
-  obs_total <- obs
-  obs_total[[obs_group]] <- "Total"
-  obs <- rbind(obs, obs_total)
   if (nrow(obs) == 0) {
     levels(obs[[obs_group]]) <- c(levels(obs[[obs_group]]), "Total")
+  } else {
+    obs_total <- obs
+    obs_total[[obs_group]] <- "Total"
+    obs <- rbind(obs, obs_total)
   }
 
   # Group information
@@ -301,22 +312,29 @@ extend_ae_specific_events <- function(outdata) {
   obs_order <- 1e2
 
   soc_events <- avg_event(obs[[obs_id]], obs[[obs_group]], obs[[par_soc]])
+  soc_events$count <- replace(soc_events$count, is.na(soc_events$count), 0)
   soc_order <- outdata$order[outdata$order %% 1e3 == 0]
+  soc_order <- soc_order[order(outdata$name[outdata$order %% 1e3 == 0])]
 
   par_events <- avg_event(obs[[obs_id]], obs[[obs_group]], obs[[par_var]])
+  par_events$count <- replace(par_events$count, is.na(par_events$count), 0)
   par_order <- outdata$order[outdata$order > 1e3 & outdata$order %% 1e3 > 0]
+  par_order <- par_order[order(outdata$name[outdata$order > 1e3 & outdata$order %% 1e3 > 0])]
 
   avg <- obs_events$avg
   se <- obs_events$se
+  count <- obs_events$count
 
   if (length(soc_order) > 0) {
     avg <- rbind(avg, soc_events$avg)
     se <- rbind(se, soc_events$se)
+    count <- rbind(count, soc_events$count)
   }
 
   if (length(par_order) > 0) {
     avg <- rbind(avg, par_events$avg)
     se <- rbind(se, par_events$se)
+    count <- rbind(count, par_events$count)
   }
 
   # Define order and add a blank row
@@ -327,13 +345,19 @@ extend_ae_specific_events <- function(outdata) {
   index <- c(index, blank_order)
 
   avg <- rbind(avg, blank_row)[order(index), ]
-  names(avg) <- paste0("events_", seq_len(ncol(avg)))
+  names(avg) <- paste0("eventsavg_", seq_len(ncol(avg)))
 
   se <- rbind(se, blank_row)[order(index), ]
   names(se) <- paste0("events_se", seq_len(ncol(se)))
 
-  outdata$events <- avg
+  count <- rbind(count, blank_row)[order(index), ]
+  names(count) <- paste0("eventscount_", seq_len(ncol(count)))
+
+  # fill NA value with zero
+  outdata$events_avg <- avg
   outdata$events_se <- se
+  # fill NA value with zero
+  outdata$events_count <- count
   outdata$extend_call <- c(outdata$extend_call, match.call())
 
   outdata
